﻿#ifndef CEDITOR_H
#define CEDITOR_H

#include "../common/sources/Map.h"
#include "bridge.h"
#include "clipboard.h"
#include <QUndoStack>

#define CURSOR_COLOR    QColor(0, 255, 0)
#define SELECTION_COLOR QColor(0, 255, 255)

struct CTileData
{
    QString name;
    QString image;
};

struct CWallData
{
    QString name;
    QString image;
};

class CEditor
{
public:
    CEditor();

    QImage      displayMap(CMap& map, CVec2 mousePos, ETabIndex tabIndex);
    EWallSide   getWallSide(CVec2 localPos);
    EWallSide   getWallSideAbs(CVec2 pos);
    bool        isSelectSingleWall();
    bool        isSelectSingleObject();
    CRect       getSelectionRect();
    QString     getPositionString(CVec2 mousePos, ETabIndex tabIndex);
    void        useTool();
    void        toolCopy();
    void        toolCut();
    void        unselect();
    void        hideSelectionInfos();
    void        initLists();

    QUndoStack* mUndoStack;
    CClipboard  mClipboard;
    CVec2       mSelectStart;
    CVec2       mSelectEnd;

    std::vector<CTileData>  tilesDatas;
    std::vector<CWallData>  wallsDatas;

private:
    CRect       getSelectionRectPixel();
    void        toolDraw();
    void        toolSelect();
    void        toolPaste();
    void        copyData(CRect rect);
    void        readTilesDB();
    void        readWallsDB();
    void        displayWall(QImage* image, CVec2 pos, EWallSide side, int angle);
};

extern CEditor  editor;

#endif // CEDITOR_H
